@@ -1,23 +1,19 @@
-# Copyright (c) 2006 Bea Lam. All rights reserved.
-# 
-# Permission is hereby granted, free of charge, to any person
-# obtaining a copy of this software and associated documentation files
-# (the "Software"), to deal in the Software without restriction,
-# including without limitation the rights to use, copy, modify, merge,
-# publish, distribute, sublicense, and/or sell copies of the Software,
-# and to permit persons to whom the Software is furnished to do so,
-# subject to the following conditions:
-# 
-# The above copyright notice and this permission notice shall be
-# included in all copies or substantial portions of the Software.
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+# Copyright (c) 2009 Bea Lam. All rights reserved.
+#
+# This file is part of LightBlue.
+#
+# LightBlue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# LightBlue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with LightBlue.  If not, see <http://www.gnu.org/licenses/>.
 
 import datetime
 import time
@@ -130,7 +126,7 @@ def _headersettodict(headerset):
     return headers
 
 
-class OBEXClient:
+class OBEXClient(object):
     __doc__ = _obexcommon._obexclientclassdoc
     
     def __init__(self, address, channel):
@@ -324,6 +320,11 @@ class OBEXClient:
         rawheaders = _headersettodict(self.__response.allHeaders())
         return _obexcommon.OBEXResponse(_cutresponsefinalbit(code), rawheaders)
 
+    def __del__(self):
+        if self.__client is not None:
+            self.__client.__del__()
+        super(OBEXClient, self).__del__()
+
     # set method docstrings
     definedmethods = locals()   # i.e. defined methods in OBEXClient
     for name, doc in _obexcommon._obexclientdocs.items():
@@ -342,6 +343,9 @@ class _BBOBEXClientDelegate(NSObject):
         return self
     initWithCallback_ = objc.selector(initWithCallback_, signature="@@:@")
 
+    def __del__(self):
+        super(_BBOBEXClientDelegate, self).dealloc()
+
     #
     # Delegate methods follow. objc signatures for all methods must be set 
     # using objc.selector or else may get bus error.
@@ -489,6 +493,9 @@ class BBOBEXObjectPushServer(NSObject):
                 
             # if client connected but didn't send PUT
             raise OBEXError(_kOBEXGeneralError, "client did not send a file")
+
+    def __del__(self):
+        super(BBOBEXObjectPushServer, self).dealloc()
         
     #
     # BBBluetoothOBEXClientDelegate methods follow.
